Module hash_set

Module hash_set 

A hash set without Drop that stores data in arena allocator.

By default uses FxHasher to hash keys. The hasher can be customized via the S type parameter (e.g. IdentBuildHasher for Ident keys).

See HashSet for more details.

Structs

Difference
A lazy iterator producing elements in the difference of HashSets.
Drain
A draining iterator over the items of a HashSet.
ExtractIf
A draining iterator over entries of a HashSet which don’t satisfy the predicate f.
HashSet
A hash set without Drop that stores data in arena allocator.
Intersection
A lazy iterator producing elements in the intersection of HashSets.
IntoIter
An owning iterator over the items of a HashSet.
Iter
An iterator over the items of a HashSet.
SymmetricDifference
A lazy iterator producing elements in the symmetric difference of HashSets.
Union
A lazy iterator producing elements in the union of HashSets.

Enums

Entry
A view into a single entry in a set, which may either be vacant or occupied.