A hash set without Drop that stores data in arena allocator.
By default uses FxHasher to hash keys. The hasher can be customized via the S type
parameter (e.g. IdentBuildHasher for Ident keys).
See HashSet for more details.
Structs
- Difference
- A lazy iterator producing elements in the difference of
HashSets. - Drain
- A draining iterator over the items of a
HashSet. - Extract
If - A draining iterator over entries of a
HashSetwhich don’t satisfy the predicatef. - HashSet
- A hash set without
Dropthat stores data in arena allocator. - Intersection
- A lazy iterator producing elements in the intersection of
HashSets. - Into
Iter - An owning iterator over the items of a
HashSet. - Iter
- An iterator over the items of a
HashSet. - Symmetric
Difference - A lazy iterator producing elements in the symmetric difference of
HashSets. - Union
- A lazy iterator producing elements in the union of
HashSets.
Enums
- Entry
- A view into a single entry in a set, which may either be vacant or occupied.