pub struct Address(/* private fields */);Expand description
Memory address of an AST node in arena.
Implementations
Sourceimpl Address
impl Address
Sourcepub fn from_ptr<T>(p: *const T) -> Self
pub fn from_ptr<T>(p: *const T) -> Self
Get the memory address of a pointer to an AST node in arena.
The pointer must point to an AST node in the arena (not on the stack),
or the returned Address will be meaningless.
If the AST node is in a Box, the address is guaranteed to be a unique identifier
for the duration of the arena’s existence.
If the node is in a Vec, then the Address may not remain accurate if the Vec
is resized or has elements added or removed before this node.