pub struct AllocatorPool { /* private fields */ }Expand description
A thread-safe pool for reusing Allocator instances to reduce allocation overhead.
Internally uses a Vec protected by a Mutex to store available allocators.
Implementations
Sourceimpl AllocatorPool
impl AllocatorPool
Sourcepub fn new(size: usize) -> AllocatorPool
pub fn new(size: usize) -> AllocatorPool
Creates a new AllocatorPool pre-filled with the given number of default AllocatorWrapper instances.
Sourcepub fn get(&self) -> AllocatorGuard<'_>
pub fn get(&self) -> AllocatorGuard<'_>
Retrieves an Allocator from the pool, or creates a new one if the pool is empty.
Returns an AllocatorGuard that gives access to the allocator.
Panics
Panics if the underlying mutex is poisoned.